==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/cloudfront/kotlin/inputs/DistributionOrderedCacheBehaviorFunctionAssociationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.cloudfront.kotlin.inputs

import com.pulumi.aws.cloudfront.inputs.DistributionOrderedCacheBehaviorFunctionAssociationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property eventType Specific event to trigger this function. Valid values: `viewer-request` or `viewer-response`.
 * @property functionArn ARN of the CloudFront function.
 */
public data class DistributionOrderedCacheBehaviorFunctionAssociationArgs(
    public val eventType: Output<String>,
    public val functionArn: Output<String>,
) :
    ConvertibleToJava<com.pulumi.aws.cloudfront.inputs.DistributionOrderedCacheBehaviorFunctionAssociationArgs> {
    override fun toJava():
        com.pulumi.aws.cloudfront.inputs.DistributionOrderedCacheBehaviorFunctionAssociationArgs =
        com.pulumi.aws.cloudfront.inputs.DistributionOrderedCacheBehaviorFunctionAssociationArgs.builder()
            .eventType(eventType.applyValue({ args0 -> args0 }))
            .functionArn(functionArn.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DistributionOrderedCacheBehaviorFunctionAssociationArgs].
 */
@PulumiTagMarker
public class DistributionOrderedCacheBehaviorFunctionAssociationArgsBuilder internal constructor() {
    private var eventType: Output<String>? = null

    private var functionArn: Output<String>? = null

    /**
     * @param value Specific event to trigger this function. Valid values: `viewer-request` or `viewer-response`.
     */
    @JvmName("dxpuuiabgxuryecv")
    public suspend fun eventType(`value`: Output<String>) {
        this.eventType = value
    }

    /**
     * @param value ARN of the CloudFront function.
     */
    @JvmName("hvgkbryxwxsshdun")
    public suspend fun functionArn(`value`: Output<String>) {
        this.functionArn = value
    }

    /**
     * @param value Specific event to trigger this function. Valid values: `viewer-request` or `viewer-response`.
     */
    @JvmName("bapqshtcrdkkvtkl")
    public suspend fun eventType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.eventType = mapped
    }

    /**
     * @param value ARN of the CloudFront function.
     */
    @JvmName("geycpcrjyjykvter")
    public suspend fun functionArn(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.functionArn = mapped
    }

    internal fun build(): DistributionOrderedCacheBehaviorFunctionAssociationArgs =
        DistributionOrderedCacheBehaviorFunctionAssociationArgs(
            eventType = eventType ?: throw PulumiNullFieldException("eventType"),
            functionArn = functionArn ?: throw PulumiNullFieldException("functionArn"),
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/cloudfront/kotlin/inputs/DistributionOrderedCacheBehaviorFunctionAssociationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.cloudfront.kotlin.inputs

import com.pulumi.aws.cloudfront.inputs.DistributionOrderedCacheBehaviorFunctionAssociationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property eventType Specific event to trigger this function. Valid values: `viewer-request` or `viewer-response`.
 * @property functionArn ARN of the CloudFront function.
 */
public data class DistributionOrderedCacheBehaviorFunctionAssociationArgs(
    public val eventType: Output<String>,
    public val functionArn: Output<String>,
) :
    ConvertibleToJava<com.pulumi.aws.cloudfront.inputs.DistributionOrderedCacheBehaviorFunctionAssociationArgs> {
    override fun toJava(): com.pulumi.aws.cloudfront.inputs.DistributionOrderedCacheBehaviorFunctionAssociationArgs =
        com.pulumi.aws.cloudfront.inputs.DistributionOrderedCacheBehaviorFunctionAssociationArgs.builder()
            .eventType(eventType.applyValue({ args0 -> args0 }))
            .functionArn(functionArn.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DistributionOrderedCacheBehaviorFunctionAssociationArgs].
 */
@PulumiTagMarker
public class DistributionOrderedCacheBehaviorFunctionAssociationArgsBuilder internal constructor() {
    private var eventType: Output<String>? = null

    private var functionArn: Output<String>? = null

    /**
     * @param value Specific event to trigger this function. Valid values: `viewer-request` or `viewer-response`.
     */
    @JvmName("hncftvqadfjtqjxu")
    public suspend fun eventType(`value`: Output<String>) {
        this.eventType = value
    }

    /**
     * @param value ARN of the CloudFront function.
     */
    @JvmName("mmdaomurtifihsat")
    public suspend fun functionArn(`value`: Output<String>) {
        this.functionArn = value
    }

    /**
     * @param value Specific event to trigger this function. Valid values: `viewer-request` or `viewer-response`.
     */
    @JvmName("iwdsmkbptkkiahcl")
    public suspend fun eventType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.eventType = mapped
    }

    /**
     * @param value ARN of the CloudFront function.
     */
    @JvmName("etolddmvbjbltbec")
    public suspend fun functionArn(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.functionArn = mapped
    }

    internal fun build(): DistributionOrderedCacheBehaviorFunctionAssociationArgs =
        DistributionOrderedCacheBehaviorFunctionAssociationArgs(
            eventType = eventType ?: throw PulumiNullFieldException("eventType"),
            functionArn = functionArn ?: throw PulumiNullFieldException("functionArn"),
        )
}
